@@ -1,6 +1,10 @@
 import logging
 from ast import literal_eval
 from asteval import Interpreter
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Parser:
@@ -11,7 +15,7 @@ class Parser:
                                 show_errors=False,
                                 raise_errors=True)
     except SyntaxError as err:
-      logging.critical(f"Invalid syntax for expression: {expression}")
+      logger.critical(f"Invalid syntax for expression: {expression}")
       raise err
 
   @staticmethod
