@@ -12,15 +12,15 @@ class Processor:
     for var, value in zip(vars, values):
       var_ptn = re.compile(var.replace("$", r"\$"))
       statement = re.sub(var_ptn, value, statement)
-    if context.store.step_item is not None:
+    if context.get_step_item() is not None:
       pattern = re.compile(r"\$step_item\$")
-      statement = re.sub(pattern, str(context.store.step_item), statement)
-    if context.store.action_item is not None:
+      statement = re.sub(pattern, str(context.get_step_item()), statement)
+    if context.get_action_item() is not None:
       pattern = re.compile(r"\$action_item\$")
-      statement = re.sub(pattern, str(context.store.action_item), statement)
-    if context.store.method_item is not None:
+      statement = re.sub(pattern, str(context.get_action_item()), statement)
+    if context.get_method_item() is not None:
       pattern = re.compile(r"\$method_item\$")
-      statement = re.sub(pattern, str(context.store.method_item), statement)
+      statement = re.sub(pattern, str(context.get_method_item()), statement)
     file_ptn = re.compile(r"\$file\$")
     filepath = f"{context.workspace.workspace_path}/"
     statement = re.sub(file_ptn, filepath, statement)
@@ -35,15 +35,15 @@ class Processor:
     for key in re.findall(store_ptn, value):
       val = context.get(key.replace("$store$", ""))
       value = value.replace(key, str(val))
-    if context.store.step_item is not None:
+    if context.get_step_item() is not None:
       pattern = re.compile(r"\$step_item\$")
-      value = re.sub(pattern, str(context.store.step_item), value)
-    if context.store.action_item is not None:
+      value = re.sub(pattern, str(context.get_step_item()), value)
+    if context.get_action_item() is not None:
       pattern = re.compile(r"\$action_item\$")
-      value = re.sub(pattern, str(context.store.action_item), value)
-    if context.store.method_item is not None:
+      value = re.sub(pattern, str(context.get_action_item()), value)
+    if context.get_method_item() is not None:
       pattern = re.compile(r"\$method_item\$")
-      value = re.sub(pattern, str(context.store.method_item), value)
+      value = re.sub(pattern, str(context.get_method_item()), value)
     file_ptn = re.compile(r"\$file\$")
     filepath = f"{context.workspace.workspace_path}/"
     value = re.sub(file_ptn, filepath, value)
