@@ -5,6 +5,10 @@ import builtins
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError, SchemaError
 from laboro.error import LaboroError
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Validator:
@@ -32,12 +36,12 @@ class Validator:
     except ValidationError as err:
       msg = {"type": "InvalidSchemaInstanceError",
              "message": f"Instance is invalid: {err.message}"}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
     except SchemaError as err:
       msg = {"type": "InvalidSchemaError",
              "message": f"Schema is invalid: {err.message}"}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def validate_method_args(self, method, args):
@@ -55,16 +59,16 @@ class Validator:
         if len(args) > 0:
           msg = {"type": "TooManyArgsError",
                  "message": f"Method does not accept args: {method['name']}"}
-          logging.critical(f"[{msg['type']}] {msg['message']}")
+          logger.critical(f"[{msg['type']}] {msg['message']}")
           raise LaboroError(f"[{msg['type']}] {msg['message']}")
         return
       if not isinstance(args, dict):
         msg = f"[MethodArgError]: Expected dict, received {type(args)}"
-        logging.critical(msg)
+        logger.critical(msg)
         raise LaboroError(msg)
       if not self._validate_required(args, method):
         msg = "[MissingRequiredArgError] Missing required argument."
-        logging.critical(msg)
+        logger.critical(msg)
         raise LaboroError(msg)
       for arg, value in args.items():
         if arg in [arg["name"] for arg in method["args"]]:
@@ -74,12 +78,12 @@ class Validator:
         else:
           msg = {"type": "UnknownMethodArgError",
                  "message": f"Unknown argument: {arg}"}
-          logging.critical(f"[{msg['type']}] {msg['message']}")
+          logger.critical(f"[{msg['type']}] {msg['message']}")
           raise LaboroError(f"[{msg['type']}] {msg['message']}")
     except AttributeError as err:
       msg = {"type": "InvalidMethodSpecTypeError",
              "message": f"Specification must be dict. Received: {type(method)}"}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def validate_obj_args(self, specification, args):
@@ -95,19 +99,19 @@ class Validator:
     """
     if not isinstance(args, dict):
       msg = f"[ModuleArgError]: Expected a dict as args, received {type(args)}"
-      logging.critical(msg)
+      logger.critical(msg)
       raise LaboroError(msg)
     obj = self._load_file(specification)
     if obj.get("args") is None:
       if len(args) > 0:
         msg = {"type": "TooManyArgsError",
                "message": f"Object constructor does not accept args: {obj['class']}"}
-        logging.critical(f"[{msg['type']}] {msg['message']}")
+        logger.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}")
       return
     if not self._validate_required(args, obj):
       msg = "[MissingRequiredArgError] Missing required argument."
-      logging.critical(msg)
+      logger.critical(msg)
       raise LaboroError(msg)
     for arg, value in args.items():
       if arg in [arg["name"] for arg in obj["args"]]:
@@ -117,7 +121,7 @@ class Validator:
       else:
         msg = {"type": "UnknownObjArgError",
                "message": f"Unknown argument: {arg}"}
-        logging.critical(f"[{msg['type']}] {msg['message']}")
+        logger.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}")
 
   def set_default_obj_args(self, specification, args):
@@ -145,13 +149,13 @@ class Validator:
     except FileNotFoundError as err:
       msg = {"type": "FileNotFoundError",
              "message": f"File not found: {filepath}"}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
     except(yaml.scanner.ScannerError,
            yaml.constructor.ConstructorError) as err:
       msg = {"type": "InvalidYamlError",
              "message": f"YAML file is invalid: {filepath}"}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def _validate_required(self, arguments, specification):
@@ -172,12 +176,12 @@ class Validator:
         if not any(allow):
           msg = {"type": "BadArgTypeError",
                  "message": f"Expected type one of {allowed_types} / received {type(value)} for {arg}."}
-          logging.critical(f"[{msg['type']}] {msg['message']}")
+          logger.critical(f"[{msg['type']}] {msg['message']}")
           raise LaboroError(f"[{msg['type']}] {msg['message']}")
       except AttributeError as err:
         msg = {"type": "UnknownTypeError",
                "message": f"Unknown type '{arg_type}' for argument {arg}."}
-        logging.critical(f"[{msg['type']}] {msg['message']}")
+        logger.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}") from err
 
   def _validate_implied(self, arg, arguments, specification):
@@ -188,7 +192,7 @@ class Validator:
     if sorted([iarg for iarg in arguments if iarg in implied]) != implied:
       msg = {"type": "MissingImpliedArgError",
              "message": f"All args of {implied} are required by {arg}."}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}")
 
   def _validate_excluded(self, arg, arguments, specification):
@@ -199,5 +203,5 @@ class Validator:
     if len([earg for earg in arguments if earg in excluded]) > 0:
       msg = {"type": "ExcludedArgError",
              "message": f"None of {' or '.join(excluded)} can be used alongside {arg}."}
-      logging.critical(f"[{msg['type']}] {msg['message']}")
+      logger.critical(f"[{msg['type']}] {msg['message']}")
       raise LaboroError(f"[{msg['type']}] {msg['message']}")
