@@ -1,5 +1,4 @@
 import re
-import copy
 import logging
 from laboro.logic.processor import Processor
 
@@ -54,25 +53,18 @@ class Method:
   def __exit__(self, kind, value, traceback):
     pass
 
-  def _get_method_args(self):
-    if self.args is not None:
-      interpolated = copy.deepcopy(self.args)
-      for key, value in interpolated.items():
-        interpolated[key] = Processor().process_arg(self.ctx, str(value))
-      return interpolated
-    return dict()
-
   def run(self):
     for item in self.iterable:
-      self.ctx.store.method_item = item
+      self.ctx.set_method_item(item)
       if self.runnable:
-        logging.getLogger("laboro.main").log_section("METHOD",
-                                        f"{self.name}")
-        method_args = self._get_method_args()
-        self.ctx.register_method_secrets(self.instance,
+        instance = self.ctx.get(self.instance)
+        self.ctx.log.log_section("METHOD",
+                                            f"{self.instance}.{self.name}")
+        method_args = self.ctx.get_method_args(self.args)
+        self.ctx.register_method_secrets(instance,
                                          self.name,
                                          method_args)
-        result = getattr(self.instance, self.name)(**method_args)
+        result = getattr(instance, self.name)(**method_args)
         if self.output is not None:
           file_ptn = re.compile(r"\$file\$")
           if re.match(file_ptn, self.output) is not None:
@@ -82,4 +74,6 @@ class Method:
             self.ctx.put(self.output, result)
       else:
         msg = f"Skipping  {self.name}: Condition not met: {self.when}"
-        logging.getLogger("laboro.main").log_section("METHOD", msg, level=logging.WARNING)
+        self.ctx.log.log_section("METHOD",
+                                            msg,
+                                            level=logging.WARNING)
