@@ -2,6 +2,10 @@ import os
 import shutil
 import logging
 from laboro.error import LaboroError
+from laboro.logger import LaboroLogger
+
+logging.setLoggerClass(LaboroLogger)
+logger = logging.getLogger("laboro.main")
 
 
 class Workspace:
@@ -28,7 +32,7 @@ class Workspace:
     try:
       self.workspace_dir = os.path.join(workspacedir, workflow)
       self.workspace_path = os.path.join(workspacedir, workflow, session)
-      logging.info(f"[+] Creating workspace: {self.workspace_path}")
+      logger.info(f"[+] Creating workspace: {self.workspace_path}")
       os.makedirs(self.workspace_path)
     except Exception as err:
       raise LaboroError(f"[{err.__class__.__name__}] {str(err)}") from err
@@ -36,7 +40,7 @@ class Workspace:
   def data_to_file(self, filename, data, mode="w",
                    encoding=None, offset=0, whence=0):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info(f"Saving file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    logger.info(f"Saving file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
     with open(filename, mode=mode, encoding=encoding) as datafile:
       datafile.seek(offset, whence)
       datafile.write(data)
@@ -44,14 +48,14 @@ class Workspace:
   def data_from_file(self, filename, length=None, mode="r",
                      encoding=None, offset=0, whence=0):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info(f"Reading file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
+    logger.info(f"Reading file: {filename} ({mode} / {encoding} / ({offset}, {whence}))")
     with open(filename, mode=mode, encoding=encoding) as datafile:
       datafile.seek(offset, whence)
       return datafile.read(length)
 
   def stream_from_file(self, filename, mode="r", encoding=None):
     filename = os.path.join(self.workspace_path, filename)
-    logging.info(f"Getting bytestream: {filename} ({mode} / {encoding})")
+    logger.info(f"Getting bytestream: {filename} ({mode} / {encoding})")
     return open(filename, mode=mode, encoding=encoding)
 
   def delete(self):
@@ -61,7 +65,7 @@ class Workspace:
     Raises:
       ``laboro.error.LaboroError``: When any error such as *OSError* while creating the workspace occurs.
     """
-    logging.info(f"[+] Deleting workspace: {self.workspace_path}")
+    logger.info(f"[+] Deleting workspace: {self.workspace_path}")
     try:
       shutil.rmtree(self.workspace_path)
     except Exception as err:
